/*
  Reduration Active Comp
    あかつきみさき

  このスクリプトについて
    アクティブなコンポジションのデュレーションを下位コンポ層を含めて一括で変更するスクリプト.
    コンポジション内のレイヤーがコンポジションの最後まである場合,レイヤーのアウトポイントも一括で変更されます.

  使用方法
    コンポジションをアクティブにしてスクリプトを実行.

  バージョン情報
    2019/05/06 Ver 1.1.0 Update
      処理済みのコンポジションに適用しないようにした.

    2017/11/04 Ver 1.0.0 Release
*/

(function () {
    CompItem.prototype.reDuration = function (newDuration, changePrecomp, applyId) {
        for (var i = 0; i < applyId.length; i++) {
            if (applyId[i] == this.id) {
                return 0;
            }
        }

        applyId[applyId.length] = this.id;

        for (var i = 1; i <= this.layers.length; i++) {
            if (this.layer(i).source instanceof CompItem && changePrecomp) {
                this.layer(i).source.reDuration(newDuration, changePrecomp, applyId);
            }

            if (!this.layer(i).locked && this.layer(i).outPoint >= this.duration) {
                this.layer(i).outPoint = newDuration;
            }
        }

        this.duration = newDuration;
    }

    var isCompActive = function (comp) {
        if (!(comp && comp instanceof CompItem)) {
            return false;
        }
        else {
            return true;
        }
    }

    var actComp = app.project.activeItem;
    if (!isCompActive(actComp)) {
        return 0;
    }

    var defaultValue = 0;
    var promptMessage = "";
    var applyId = [];

    app.beginUndoGroup("Reduration Active Comp");
    if (app.project.timeDisplayType == TimeDisplayType.FRAMES) {
        defaultValue = actComp.duration / actComp.frameDuration;
        promptMessage = "新規フレーム数を入力してください\nNew duration (frame)";
    } else {
        defaultValue = actComp.duration;
        promptMessage = "新規秒数を入力してください\nNew duration (second)";
    }

    var newDuration = prompt(promptMessage, defaultValue, "Reduration Active Comp");
    if (app.project.timeDisplayType == TimeDisplayType.FRAMES) {
        newDuration = newDuration * actComp.frameDuration;
    } else {
        newDuration = newDuration;
    }

    if (newDuration > 0 && !isNaN(newDuration)) {
        actComp.reDuration(newDuration, true, applyId);
    }

    app.endUndoGroup();
    return 0;
}).call(this);
